@@ -32,7 +32,7 @@ from ..extensions import ExtensionManager
 from .. import pipeline
 from .. import session
 
-from .._version import version as __version__
+from .._version import version
 
 
 # global plotting configuration parameters
@@ -96,7 +96,7 @@ class ShapeOut2(QtWidgets.QMainWindow):
                 + traceback.format_exc(),
                 )
         # GUI
-        self.setWindowTitle("Shape-Out {}".format(__version__))
+        self.setWindowTitle(f"Shape-Out {version}")
         # Disable native menu bar (e.g. on Mac)
         self.menubar.setNativeMenuBar(False)
         # File menu
@@ -187,7 +187,7 @@ class ShapeOut2(QtWidgets.QMainWindow):
         self.widget_ana_view.slot_changed.connect(self.adopt_slot)
         # if "--version" was specified, print the version and exit
         if "--version" in arguments:
-            print(__version__)
+            print(version)
             QtWidgets.QApplication.processEvents(QtCore.QEventLoop.AllEvents,
                                                  300)
             sys.exit(0)
@@ -453,6 +453,16 @@ class ShapeOut2(QtWidgets.QMainWindow):
             sub.setFixedSize(sub.sizeHint())
         sub.show()
 
+    def closeEvent(self, event):
+        """Determine what happens when the user wants to quit"""
+        if self.pipeline.slots or self.pipeline.filters:
+            if self.on_action_clear():
+                event.accept()
+            else:
+                event.ignore()
+        else:
+            event.accept()
+
     def dragEnterEvent(self, e):
         """Whether files are accepted"""
         if e.mimeData().hasUrls():
@@ -516,9 +526,7 @@ class ShapeOut2(QtWidgets.QMainWindow):
             + "<a href='https://github.com/{gh}'>{gh}</a><br>".format(gh=gh) \
             + "Documentation: " \
             + "<a href='https://{rtd}'>{rtd}</a><br>".format(rtd=rtd)
-        QtWidgets.QMessageBox.about(self,
-                                    "Shape-Out {}".format(__version__),
-                                    about_text)
+        QtWidgets.QMessageBox.about(self, f"Shape-Out {version}", about_text)
 
     @QtCore.pyqtSlot()
     def on_action_change_dataset_order(self):
@@ -539,7 +547,6 @@ class ShapeOut2(QtWidgets.QMainWindow):
                 self.on_action_check_update_finished)
             self._update_thread.start()
 
-            version = __version__
             ghrepo = "ZELLMECHANIK-DRESDEN/ShapeOut2"
 
             QtCore.QMetaObject.invokeMethod(self._update_worker,
@@ -597,31 +604,34 @@ class ShapeOut2(QtWidgets.QMainWindow):
         dlg.exec()
 
     @QtCore.pyqtSlot()
-    def on_action_clear(self, assume_yes=False):
-        if assume_yes:
-            yes = True
-        else:
+    def on_action_clear(self):
+        """Clear the entire session"""
+        if bool(int(self.settings.value("advanced/user confirm clear", "1"))):
             button_reply = QtWidgets.QMessageBox.question(
                 self, 'Clear Session', "All progress will be lost. Continue?",
                 QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No,
                 QtWidgets.QMessageBox.No)
             yes = button_reply == QtWidgets.QMessageBox.Yes
+        else:
+            yes = True
         if yes:
             session.clear_session(self.pipeline)
             self.reload_pipeline()
+            self.setWindowTitle(f"Shape-Out {version}")
         return yes
 
     @QtCore.pyqtSlot()
-    def on_action_clear_datasets(self, assume_yes=False):
-        if assume_yes:
-            yes = True
-        else:
+    def on_action_clear_datasets(self):
+        """Clear only the datasets"""
+        if bool(int(self.settings.value("advanced/user confirm clear", "1"))):
             button_reply = QtWidgets.QMessageBox.question(
                 self, 'Clear Datasets',
                 "Remove all datasets from this session?",
                 QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No,
                 QtWidgets.QMessageBox.No)
             yes = button_reply == QtWidgets.QMessageBox.Yes
+        else:
+            yes = True
         if yes:
             for slot_id in self.pipeline.slot_ids:
                 self.pipeline.remove_slot(slot_id)
@@ -707,11 +717,14 @@ class ShapeOut2(QtWidgets.QMainWindow):
                 else:
                     break
             self.reload_pipeline()
+            self.setWindowTitle(
+                f"{pathlib.Path(path).name} [Shape-Out {version}]")
 
     @QtCore.pyqtSlot()
     def on_action_preferences(self):
-        """Show the DCOR import dialog"""
+        """Show the preferences dialog"""
         dlg = preferences.Preferences(self)
+        dlg.setWindowTitle("Shape-Out Preferences")
         dlg.feature_changed.connect(self.plots_changed)
         dlg.feature_changed.connect(self.on_quickview_refresh)
         dlg.exec()
@@ -732,6 +745,8 @@ class ShapeOut2(QtWidgets.QMainWindow):
             if not path.endswith(".so2"):
                 path += ".so2"
             session.save_session(path, self.pipeline)
+            self.setWindowTitle(
+                f"{pathlib.Path(path).name} [Shape-Out {version}]")
 
     @QtCore.pyqtSlot()
     def on_action_software(self):
@@ -744,18 +759,16 @@ class ShapeOut2(QtWidgets.QMainWindow):
         if not isinstance(rpy2, MockRPackage):
             libs.append(rpy2)
 
-        sw_text = "Shape-Out {}\n\n".format(__version__)
-        sw_text += "Python {}\n\n".format(sys.version)
+        sw_text = f"Shape-Out {version}\n\n"
+        sw_text += f"Python {sys.version}\n\n"
         sw_text += "Modules:\n"
         for lib in libs:
-            sw_text += "- {} {}\n".format(lib.__name__, lib.__version__)
-        sw_text += "- PyQt5 {}\n".format(QtCore.QT_VERSION_STR)
+            sw_text += f"- {lib.__name__} {lib.__version__}\n"
+        sw_text += f"- PyQt5 {QtCore.QT_VERSION_STR}\n"  # Extrawurst
         sw_text += "\n Breeze icon theme by the KDE Community (LGPL)."
         if hasattr(sys, 'frozen'):
             sw_text += "\nThis executable has been created using PyInstaller."
-        QtWidgets.QMessageBox.information(self,
-                                          "Software",
-                                          sw_text)
+        QtWidgets.QMessageBox.information(self, "Software", sw_text)
 
     @QtCore.pyqtSlot(int)
     def on_remove_polygon_filter_from_pipeline(self, pf_id):
@@ -908,8 +921,7 @@ def excepthook(etype, value, trace):
         prints the standard Python header: ``Traceback (most recent
         call last)``.
     """
-    vinfo = "Unhandled exception in Shape-Out version {}:\n".format(
-        __version__)
+    vinfo = f"Unhandled exception in Shape-Out version {version}:\n"
     tmp = traceback.format_exception(etype, value, trace)
     exception = "".join([vinfo]+tmp)
 
