@@ -210,7 +210,7 @@ class PipelinePlot(QtWidgets.QWidget):
             colorbar = ShapeOutColorBarItem(
                 yoffset=31,  # this is heuristic
                 height=min(300, lay["size y"] // 2),
-                cmap=cmap,
+                colorMap=cmap,
                 interactive=False,
                 width=15,
                 **colorbar_kwds
@@ -349,7 +349,7 @@ class PipelinePlotItem(SimplePlotItem):
 
                 if plot_state["scatter"]["show event count"]:
                     if True:
-                        add_label(text="{} events".format(len(sct[0].data)),
+                        add_label(text=f"{len(sct[0].data)} events",
                                   anchor_parent=self.axes["right"]["item"],
                                   font_size_diff=-1,
                                   color="black",
@@ -436,48 +436,17 @@ def add_label(text, anchor_parent, text_halign="center", text_valign="center",
 
 
 def add_contour(plot_item, plot_state, rtdc_ds, slot_state, legend=None):
-    gen = plot_state["general"]
+    contours = compute_contours(plot_state=plot_state, rtdc_ds=rtdc_ds)
     con = plot_state["contour"]
-    try:
-        x, y, density = plot_cache.get_contour_data(
-            rtdc_ds=rtdc_ds,
-            xax=gen["axis x"],
-            yax=gen["axis y"],
-            xacc=con["spacing x"],
-            yacc=con["spacing y"],
-            xscale=gen["scale x"],
-            yscale=gen["scale y"],
-            kde_type=gen["kde"],
-        )
-    except ValueError:
-        # most-likely there is nothing to compute a contour for
-        return []
-    if density.shape[0] < 3 or density.shape[1] < 3:
-        warnings.warn("Contour not possible; spacing may be too large!",
-                      ContourSpacingTooLarge)
-        return []
-    plev = kde_contours.get_quantile_levels(
-        density=density,
-        x=x,
-        y=y,
-        xp=rtdc_ds[gen["axis x"]][rtdc_ds.filter.all],
-        yp=rtdc_ds[gen["axis y"]][rtdc_ds.filter.all],
-        q=np.array(con["percentiles"])/100,
-        normalize=True)
-    contours = []
-    for level in plev:
-        # make sure that the contour levels are not at the boundaries
-        if not (np.allclose(level, 0, atol=1e-12, rtol=0)
-                or np.allclose(level, 1, atol=1e-12, rtol=0)):
-            cc = kde_contours.find_contours_level(
-                density, x=x, y=y, level=level)
-            contours.append(cc)
-
     elements = []
+    num_unreliable_contours = 0
     for ii in range(len(contours)):
         style = linestyles[con["line styles"][ii]]
         width = con["line widths"][ii]
         for cci in contours[ii]:
+            if not compute_contour_reliable(plot_state=plot_state,
+                                            contour=cci):
+                num_unreliable_contours += 1
             cline = pg.PlotDataItem(x=cci[:, 0],
                                     y=cci[:, 1],
                                     pen=pg.mkPen(color=slot_state["color"],
@@ -492,6 +461,16 @@ def add_contour(plot_item, plot_state, rtdc_ds, slot_state, legend=None):
             # Always plot higher percentiles above lower percentiles
             # (useful if there are multiple contour plots overlapping)
             cline.setZValue(con["percentiles"][ii])
+    if num_unreliable_contours or not elements:
+        # Tell the user to refine contour spacing.
+        add_label("Please reduce contour spacing.",
+                  anchor_parent=plot_item.axes["bottom"]["item"],
+                  font_size_diff=-1,
+                  color="red",
+                  text_halign="left",
+                  text_valign="bottom",
+                  dy=-12,
+                  )
     return elements
 
 
@@ -597,6 +576,104 @@ def add_scatter(plot_item, plot_state, rtdc_ds, slot_state):
     return [scatter]
 
 
+def compute_contours(plot_state, rtdc_ds):
+    gen = plot_state["general"]
+    con = plot_state["contour"]
+    try:
+        x, y, density = plot_cache.get_contour_data(
+            rtdc_ds=rtdc_ds,
+            xax=gen["axis x"],
+            yax=gen["axis y"],
+            xacc=con["spacing x"],
+            yacc=con["spacing y"],
+            xscale=gen["scale x"],
+            yscale=gen["scale y"],
+            kde_type=gen["kde"],
+        )
+    except ValueError:
+        # most-likely there is nothing to compute a contour for
+        return []
+    if density.shape[0] < 3 or density.shape[1] < 3:
+        warnings.warn("Contour not possible; spacing may be too large!",
+                      ContourSpacingTooLarge)
+        return []
+    plev = kde_contours.get_quantile_levels(
+        density=density,
+        x=x,
+        y=y,
+        xp=rtdc_ds[gen["axis x"]][rtdc_ds.filter.all],
+        yp=rtdc_ds[gen["axis y"]][rtdc_ds.filter.all],
+        q=np.array(con["percentiles"]) / 100,
+        normalize=True)
+    contours = []
+    for level in plev:
+        # make sure that the contour levels are not at the boundaries
+        if not (np.allclose(level, 0, atol=1e-12, rtol=0)
+                or np.allclose(level, 1, atol=1e-12, rtol=0)):
+            cc = kde_contours.find_contours_level(
+                density, x=x, y=y, level=level)
+            contours.append(cc)
+    return contours
+
+
+def compute_contour_opening_angles(plot_state, contour):
+    """For each point of the contour, compute the opening angle
+
+    This takes the visible plot area into account.
+    """
+    cc = np.array(contour, copy=True)
+    if not np.all(cc[0] == cc[-1]):
+        cc = np.resize(cc, (len(contour)+1, 2))
+    # Normalize contour
+    rx = plot_state["general"]["range x"]
+    ry = plot_state["general"]["range y"]
+    cc[:, 0] = (cc[:, 0] - rx[0]) / (rx[1] - rx[0])
+    cc[:, 1] = (cc[:, 1] - ry[0]) / (ry[1] - ry[0])
+    # apply scale
+    sx = plot_state["general"]["scale x"]
+    assert sx in ["log", "linear"]
+    if sx == "log":
+        cc[:, 0] = np.log10(cc[:, 0])
+    sy = plot_state["general"]["scale y"]
+    assert sy in ["log", "linear"]
+    if sy == "log":
+        cc[:, 1] = np.log10(cc[:, 1])
+    opang = np.zeros(len(cc)-1, dtype=float)
+    for jj, c0 in enumerate(cc[:-1]):  # we have a closed contour
+        cl = cc[:-1][jj - 1]
+        cr = cc[jj + 1]
+        # vector a
+        a = np.array(cl) - np.array(c0)
+        # vector b
+        b = np.array(cr) - np.array(c0)
+        absa = np.sqrt(np.sum(a ** 2))
+        absb = np.sqrt(np.sum(b ** 2))
+        phi = np.arccos(np.sum(a * b) / (absa * absb))
+        if np.abs(phi) > np.pi/2:
+            phi -= np.sign(phi) * np.pi
+        opang[jj] = phi
+    return opang
+
+
+def compute_contour_reliable(plot_state, contour, thresh_ang=np.deg2rad(23)):
+    """Determine whether contour is reliable or not"""
+    # Compute the opening angle for each point of the
+    # contour and take the point with the largest opening angle.
+    angles = compute_contour_opening_angles(
+        plot_state=plot_state, contour=contour)
+    if (np.allclose(np.abs(angles[0]), np.pi / 2)
+            and np.all(angles[1:6] == 0)):
+        # We have probably encountered a contour at the boundary
+        # of the image. It looks like this is ok.
+        reliable = True
+    elif len(angles) > 50:
+        # The contour is long enough to be trusted.
+        reliable = True
+    else:
+        reliable = np.max(np.abs(angles)) <= thresh_ang
+    return reliable
+
+
 def get_axes_labels(plot_state, slot_states):
     gen = plot_state["general"]
     # Use slot_states[0] because we only have one x-axis label
